@@ -2,6 +2,6 @@ s.wrapper <-
 function(a, b, max.obj, geno, locustype, r, s, alleles){
   f.a <- support.limit(h=a, geno, locustype, r, s, alleles, max.obj)
   f.b <- support.limit(h=b, geno, locustype, r, s, alleles, max.obj)
-  ifelse(f.a * f.b <= 0, TRUE, FALSE) 
+  f.a * f.b <= 0
 }
 
